==> ejc-trade-api-3.0.0-20220708.092619-17-sources.jar: com/ejianc/business/trade/vo/SaleLibraryVO.java <==
package com.ejianc.business.trade.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.trade.vo.SaleLibraryZiVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 销售库
 * 
 * @author generator
 * 
 */
public class SaleLibraryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 销售单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long receiveId; // 收货单id\
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date receiveDate; // 签收日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date accountsDueDate; // 应收款日期
    private Integer receiveNum; // 收货总数
    private BigDecimal receivePrice; // 收货总金额
    private String xxpbm; // 销项票编码
    private Integer htzq; // 合同周期
    private BigDecimal yx; // 月息
    private BigDecimal purchasePrice; // 采购总金额
    private BigDecimal cj; // 差价
    private BigDecimal qkzje; // 欠款总金额


    public BigDecimal getQkzje() {
        return qkzje;
    }

    public void setQkzje(BigDecimal qkzje) {
        this.qkzje = qkzje;
    }
    private List<SaleLibraryZiVO> saleLibraryZiList = new ArrayList<>(); // 销售库子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getReceiveId() {
        return receiveId;
    }

    public void setReceiveId(Long receiveId) {
        this.receiveId = receiveId;
    }
    public Date getReceiveDate() {
        return receiveDate;
    }

    public void setReceiveDate(Date receiveDate) {
        this.receiveDate = receiveDate;
    }
    public Date getAccountsDueDate() {
        return accountsDueDate;
    }

    public void setAccountsDueDate(Date accountsDueDate) {
        this.accountsDueDate = accountsDueDate;
    }
    public Integer getReceiveNum() {
        return receiveNum;
    }

    public void setReceiveNum(Integer receiveNum) {
        this.receiveNum = receiveNum;
    }
    public BigDecimal getReceivePrice() {
        return receivePrice;
    }

    public void setReceivePrice(BigDecimal receivePrice) {
        this.receivePrice = receivePrice;
    }
    public String getXxpbm() {
        return xxpbm;
    }

    public void setXxpbm(String xxpbm) {
        this.xxpbm = xxpbm;
    }
    public Integer getHtzq() {
        return htzq;
    }

    public void setHtzq(Integer htzq) {
        this.htzq = htzq;
    }
    public BigDecimal getYx() {
        return yx;
    }

    public void setYx(BigDecimal yx) {
        this.yx = yx;
    }
    public BigDecimal getPurchasePrice() {
        return purchasePrice;
    }

    public void setPurchasePrice(BigDecimal purchasePrice) {
        this.purchasePrice = purchasePrice;
    }
    public BigDecimal getCj() {
        return cj;
    }

    public void setCj(BigDecimal cj) {
        this.cj = cj;
    }
    
     public List<SaleLibraryZiVO> getSaleLibraryZiList() {
        return saleLibraryZiList;
     }

     public void setSaleLibraryZiList(List<SaleLibraryZiVO> saleLibraryZiList) {
        this.saleLibraryZiList = saleLibraryZiList;
     }
}

==> ejc-trade-api-3.0.0-20220811.065326-18-sources.jar: com/ejianc/business/trade/vo/SaleLibraryVO.java <==
package com.ejianc.business.trade.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.trade.vo.SaleLibraryZiVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 销售库
 * 
 * @author generator
 * 
 */
public class SaleLibraryVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String billCode; // 销售单据编码
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Integer billState; // 单据状态（审批必须字段）
    private String createUserName; // 编制人
    private Long operatorId; // 经办人ID
    private String operatorName; // 经办人姓名
    private String updateUserName; // 修改者
    private String remark; // 备注
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long receiveId; // 收货单id\
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date receiveDate; // 签收日期
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date accountsDueDate; // 应收款日期
    private Integer receiveNum; // 收货总数
    private BigDecimal receivePrice; // 收货总金额
    private String xxpbm; // 销项票编码
    private Integer htzq; // 合同周期
    private BigDecimal yx; // 月息
    private BigDecimal purchasePrice; // 采购总金额
    private BigDecimal cj; // 差价
    private BigDecimal qkzje; // 欠款总金额
    private String sfkjxp; // 是否开进项票


    public String getSfkjxp() {
        return sfkjxp;
    }

    public void setSfkjxp(String sfkjxp) {
        this.sfkjxp = sfkjxp;
    }


    public BigDecimal getQkzje() {
        return qkzje;
    }

    public void setQkzje(BigDecimal qkzje) {
        this.qkzje = qkzje;
    }
    private List<SaleLibraryZiVO> saleLibraryZiList = new ArrayList<>(); // 销售库子表

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Long getReceiveId() {
        return receiveId;
    }

    public void setReceiveId(Long receiveId) {
        this.receiveId = receiveId;
    }
    public Date getReceiveDate() {
        return receiveDate;
    }

    public void setReceiveDate(Date receiveDate) {
        this.receiveDate = receiveDate;
    }
    public Date getAccountsDueDate() {
        return accountsDueDate;
    }

    public void setAccountsDueDate(Date accountsDueDate) {
        this.accountsDueDate = accountsDueDate;
    }
    public Integer getReceiveNum() {
        return receiveNum;
    }

    public void setReceiveNum(Integer receiveNum) {
        this.receiveNum = receiveNum;
    }
    public BigDecimal getReceivePrice() {
        return receivePrice;
    }

    public void setReceivePrice(BigDecimal receivePrice) {
        this.receivePrice = receivePrice;
    }
    public String getXxpbm() {
        return xxpbm;
    }

    public void setXxpbm(String xxpbm) {
        this.xxpbm = xxpbm;
    }
    public Integer getHtzq() {
        return htzq;
    }

    public void setHtzq(Integer htzq) {
        this.htzq = htzq;
    }
    public BigDecimal getYx() {
        return yx;
    }

    public void setYx(BigDecimal yx) {
        this.yx = yx;
    }
    public BigDecimal getPurchasePrice() {
        return purchasePrice;
    }

    public void setPurchasePrice(BigDecimal purchasePrice) {
        this.purchasePrice = purchasePrice;
    }
    public BigDecimal getCj() {
        return cj;
    }

    public void setCj(BigDecimal cj) {
        this.cj = cj;
    }
    
     public List<SaleLibraryZiVO> getSaleLibraryZiList() {
        return saleLibraryZiList;
     }

     public void setSaleLibraryZiList(List<SaleLibraryZiVO> saleLibraryZiList) {
        this.saleLibraryZiList = saleLibraryZiList;
     }
}
